@@ -106,7 +106,7 @@ class OpenPR:
             sys.exit(-1)
 
         if youtrack_id:
-            self._youtrack.comment(youtrack_id, f"PR {self._project} -> {link}")
+            self._youtrack.comment(youtrack_id, f"PR {self._project} -> {pr.html_url}")
             logger.info(f"Inserito link della pull request nella card {youtrack_id}")
 
         if prompt_utils.ask_confirm("Vuoi inserire i reviewers?"):
